*********************************
The sherpa.models.template module
*********************************

.. currentmodule:: sherpa.models.template

.. automodule:: sherpa.models.template

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      TemplateModel
      InterpolatingTemplateModel
      KNNInterpolator
      Template
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: TemplateModel InterpolatingTemplateModel KNNInterpolator Template
   :parts: 1


